@@ -117,18 +117,19 @@ class Gateway():
         logging.debug('Gateway writting: ' + str(commandstr))
 
         try:
-            if self.ser.isOpen():
-                self.ser.write(commandstr)
-                if self.configure:
-                    time.sleep(0.5)
-                    response_str = "" 
-                    while True:
-                        response = self.ser.readall()
-                        response_str += str(response.decode())
-                        #print(response_str)
-                        logging.debug('read data: ' + response_str)  
-                        if (response.decode()== ''):
-                            break
+            if not self.ser.isOpen():
+            self.configserial()
+            self.ser.write(commandstr)
+            if self.configure:
+                time.sleep(0.5)
+                response_str = "" 
+                while True:
+                    response = self.ser.readall()
+                    response_str += str(response.decode())
+                    #print(response_str)
+                    logging.debug('read data: ' + response_str)  
+                    if (response.decode()== ''):
+                        break
                     #     data_str = ""
                     # while (self.ser.inWaiting() > 0):
                     #     data_str += self.ser.readline(self.ser.inWaiting()).decode('ascii') #read the bytes and convert from binary array to ASCII
@@ -260,7 +261,7 @@ if __name__ == '__main__':
     content_mapping = gat.get_input_list()
     #source_list = [key for key in content_mapping]
     #gat.turn_on()
-    gat.refresh_power_status()
+    print(gat.get_power_status())
     #print(gat.get_status())
     #print(source_list)
     # for key in content_mapping:
